/* libide-tweaks.h
 *
 * Copyright 2022 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#define IDE_TWEAKS_INSIDE
# include "ide-tweaks.h"
# include "ide-tweaks-addin.h"
# include "ide-tweaks-binding.h"
# include "ide-tweaks-caption.h"
# include "ide-tweaks-choice.h"
# include "ide-tweaks-combo.h"
# include "ide-tweaks-combo-row.h"
# include "ide-tweaks-directory.h"
# include "ide-tweaks-entry.h"
# include "ide-tweaks-factory.h"
# include "ide-tweaks-font.h"
# include "ide-tweaks-group.h"
# include "ide-tweaks-info.h"
# include "ide-tweaks-item.h"
# include "ide-tweaks-page.h"
# include "ide-tweaks-property.h"
# include "ide-tweaks-radio.h"
# include "ide-tweaks-section.h"
# include "ide-tweaks-setting.h"
# include "ide-tweaks-spin.h"
# include "ide-tweaks-switch.h"
# include "ide-tweaks-widget.h"
# include "ide-tweaks-window.h"
#undef IDE_TWEAKS_INSIDE
